module Organizer
  class Request
    attr_accessor :path, :query

    def initialize(path = "", query = {})
      @path = path
      @query = query
    end

    def get
      response = api.get(path, query)
      Response.new(response)
    end

    def post
      response = api.post do |req|
        req.url path
        req.headers['Content-Type'] = 'application/json'
        req.body = query.to_json
      end
      Response.new(response)
    end

    def put
      response = api.put do |req|
        req.url path
        req.headers['Content-Type'] = 'application/json'
        req.body = query.to_json
      end
      Response.new(response)
    end

    def delete
      response = api.delete(path, query)
      Response.new(response)
    end

    def method_missing(method, *args)
      params = args[0].is_a?(Hash) ? args[0] : {}
      id = params.delete(:id)
      route = path + "#{method}/#{id}"
      Request.new(route, params)
    end

    private
    def api
      Faraday.new(Config.url_prefix, {params: {token: Config.access_token}})
    end
  end
end